@@ -61,7 +61,7 @@ class GlobalData:
 
 @dataclass(frozen=True)
 class TaskInput:
-    fname: Path
+    fpath: Path
     mime: MIME
 
 
@@ -141,17 +141,23 @@ class TaskThumbnails(Task):
             utils.mkdir(subpath, dir_mod)
 
     def do_single(self, inp, *, sizes, largest_size, **kwargs):
-        logger.debug('- %s', inp.fname)
+        logger.debug('- %s', inp.fpath)
+        if inp.fpath.is_symlink():
+            inp_fpath = Path(os.readlink(inp.fpath))  # Don't resolve
+            assert not inp_fpath.is_absolute()  # Unsupported absolute symlink
+            logger.debug('| Link To: %s', inp_fpath)
+        else:
+            inp_fpath = inp.fpath
         creator = self.creators[inp.mime.type]
         result = dict()
         for size in sizes:
-            result[size] = self.do_thumbnail(inp.fname, size, creator, mime=inp.mime.type, **kwargs)
+            result[size] = self.do_thumbnail(inp_fpath, size, creator, mime=inp.mime.type, isrc=inp.fpath, **kwargs)
         if None in result.values():
-            logger.error('Broken File: %s', inp.fname)
+            logger.error('Broken File: %s', inp_fpath)
         return result[largest_size]  # Show only the biggest size on the HTML
 
-    def do_thumbnail(self, ifname, size, creator, mime, *, args, **kwargs):
-        tpath = utils.thumbnail_path(ifname, size, args.format, basedir=args.basedir)
+    def do_thumbnail(self, ifpath, size, creator, mime, isrc, *, args, **kwargs):
+        tpath = utils.thumbnail_path(ifpath, size, args.format, basedir=args.basedir)
         logger.debug('Thumbnail: %s', tpath)
         existing = tpath.exists()
         result = True
@@ -161,10 +167,11 @@ class TaskThumbnails(Task):
         if args.force or not existing:
             logger.debug('- Saving ...')
             try:
-                result = creator.thumbnail(ifname, tpath,
+                result = creator.thumbnail(ifpath, tpath,
                                            size=size,
                                            fmt=args.format, mime=mime,
                                            template=args.template,
+                                           isrc=isrc,
                                            verbose=args.verbose,
                                            # MIME Type-specific
                                            overlay=args.thumb_overlay)
@@ -178,9 +185,10 @@ class TaskThumbnails(Task):
         else:
             logger.debug('- Skipping!')
         if result is not None:
-            result = creator.info(ifname, tpath,
+            result = creator.info(ifpath, tpath,
                                   size=size,
                                   fmt=args.format, mime=mime,
+                                  isrc=isrc,
                                   verbose=args.verbose)
 
         return result
@@ -213,8 +221,8 @@ class TaskTracks(Task):
         # https://www.topografix.com/GPX/1/1/#type_metadataType
         # XPath: /metadata/name
         return {
-            'title': inp.fname.stem,
-            'url': inp.fname.relative_to(args.basedir),
+            'title': inp.fpath.stem,
+            'url': inp.fpath.relative_to(args.basedir),
         }
 
     def do_post(self, *, jinja, args, gdata, **kwargs):
@@ -407,7 +415,7 @@ def __main__():
         if task.todo:
             logger.debug('- %s| %d items', task.message, len(task.inputs))
             # for tin in task.inputs:
-            #     logger.debug('  > %s| %s', tin.mime.type, tin.fname)
+            #     logger.debug('  > %s| %s', tin.mime.type, tin.fpath)
             task.doit(**locals())  # This is a very ugly hack...
             # for tout in task.outputs:
             #     logger.debug('  < %r', tout)
