@@ -69,6 +69,8 @@ function showTrackIndex(index) {
 	})
 	// Jump to view
 	map.fitBounds(track.getBounds())
+	// Change the URL
+	history.replaceState(true, '', `#${index}`);
 }
 
 function clickLayer(e) {
@@ -176,7 +178,8 @@ for (let track_name in GLOBAL_DATA['tracks']) {
 // Get the track index from the window hash
 var track_hash = window.location.hash.substring(1)
 var track_number = Number(track_hash)
-if (track_hash !== "" && track_number !== NaN) {
+if (track_hash !== "" && track_number !== NaN && track_number < tracks.length) {
+	console.log("Using track number from URL")
 	default_track = track_number
 }
 tracks[default_track].once('loaded', (e) => {
