@@ -64,11 +64,11 @@ def image_title(image: Image, ipath: Path):
     return ipath.stem
 
 
-def thumbnail(ifile: Path, ofile: Path, *, size: XDG_SIZE, fmt: Format, mime: str, template=[], verbose=False, **options):
+def thumbnail(ifile: Path, ofile: Path, *, size: XDG_SIZE, fmt: Format, mime: str, template=[], isrc=None, verbose=False, **options):
     image = Image.open(ifile)
     o_size = image_size(image)
     o_time = image_time(image, ifile)
-    o_title = image_title(image, ifile)
+    o_title = image_title(image, isrc or ifile)
     ops = []
     # Only if EXIF information is exposed
     if getattr(image, '_getexif'):
@@ -98,12 +98,12 @@ def thumbnail(ifile: Path, ofile: Path, *, size: XDG_SIZE, fmt: Format, mime: st
     )
 
 
-def info(ifile: Path, ofile: Path, *, size: XDG_SIZE, fmt: Format, mime: str, template=[], verbose=False, **options):
+def info(ifile: Path, ofile: Path, *, size: XDG_SIZE, fmt: Format, mime: str, template=[], isrc=None, verbose=False, **options):
     image = Image.open(ifile)
     return utils.ThumbnailData(
         path=ofile,
         original=ifile,
-        title=image_title(image, ifile),
+        title=image_title(image, isrc or ifile),
         size=image_size(image),
         time=image_time(image, ifile),
         mime=fmt.mime,
