@@ -54,7 +54,7 @@ def video_time(probe, ipath: Path):
     )
 
 
-def thumbnail(ifile: Path, ofile: Path, *, size: XDG_SIZE, fmt: Format, mime: str, template=[], verbose=False, overlay=None, **options):
+def thumbnail(ifile: Path, ofile: Path, *, size: XDG_SIZE, fmt: Format, mime: str, template=[], isrc=None, verbose=False, overlay=None, **options):
     loglevel = ['-v', 'quiet']
     if verbose:
         loglevel = []
@@ -123,7 +123,7 @@ def thumbnail(ifile: Path, ofile: Path, *, size: XDG_SIZE, fmt: Format, mime: st
     return utils.ThumbnailData(
         path=ofile,
         original=ifile,
-        title=video_title(probe, ifile),
+        title=video_title(probe, isrc or ifile),
         size=video_size(probe),
         time=video_time(probe, ifile),
         mime=fmt.mime,
@@ -131,12 +131,12 @@ def thumbnail(ifile: Path, ofile: Path, *, size: XDG_SIZE, fmt: Format, mime: st
     )
 
 
-def info(ifile: Path, ofile: Path, *, size: XDG_SIZE, fmt: Format, mime: str, template=[], verbose=False, overlay=None, **options):
+def info(ifile: Path, ofile: Path, *, size: XDG_SIZE, fmt: Format, mime: str, template=[], isrc=None, verbose=False, overlay=None, **options):
     probe = _probe(ifile, verbose)
     return utils.ThumbnailData(
         path=ofile,
         original=ifile,
-        title=video_title(probe, ifile),
+        title=video_title(probe, isrc or ifile),
         size=video_size(probe),
         time=video_time(probe, ifile),
         mime=fmt.mime,
